#! /usr/bin/python3
from __future__ import division
import time
import Adafruit_SSD1306   # This is the driver chip for the Adafruit PiOLED
from PIL import Image
from PIL import ImageDraw
from PIL import ImageFont
import board
import busio
import adafruit_bme280
import subprocess
import RPi.GPIO as GPIO

import time
import Adafruit_PCA9685

def get_network_interface_state(interface):
    return subprocess.check_output('cat /sys/class/net/%s/operstate' % interface, shell=True).decode('ascii')[:-1]

def get_ip_address(interface):
    if get_network_interface_state(interface) == 'down':
        return None
    cmd = "ifconfig %s | grep -Eo 'inet (addr:)?([0-9]*\.){3}[0-9]*' | grep -Eo '([0-9]*\.){3}[0-9]*' | grep -v '127.0.0.1'" % interface
    return subprocess.check_output(cmd, shell=True).decode('ascii')[:-1]
# ------------------------------------ oled --------------------------------
print(">>> Preparing OLED ...")
# 128x64 display with hardware I2C:
# setting gpio to 1 is hack to avoid platform detection

disp = Adafruit_SSD1306.SSD1306_128_64(rst=None, i2c_bus=1, gpio=1)

# Initialize library.
disp.begin()

# Clear display.
disp.clear()
disp.display()

# Create blank image for drawing.
# Make sure to create image with mode '1' for 1-bit color.
width = disp.width
height = disp.height
image = Image.new('1', (width, height))

# Get drawing object to draw on image.
draw = ImageDraw.Draw(image)

# Draw a black filled box to clear the image.
draw.rectangle((0, 0, width, height), outline=0, fill=0)

# Load default font.
font = ImageFont.load_default()

# ------------------------------------------------------ bme280 ------------------------

# Create library object using our Bus I2C port
# bme280 i2c address: 0x77
i2c = busio.I2C(board.SCL, board.SDA)
bme280 = adafruit_bme280.Adafruit_BME280_I2C(i2c)

# OR create library object using our Bus SPI port
#spi = busio.SPI(board.SCK, board.MOSI, board.MISO)
#bme_cs = digitalio.DigitalInOut(board.D10)
#bme280 = adafruit_bme280.Adafruit_BME280_SPI(spi, bme_cs)

# change this to match the location's pressure (hPa) at sea level

bme280.sea_level_pressure = 1013.25
adj_t = -3
adj_h = -5
adj_p = -13
adj_a = 0
print(">>> Displaying weather data ...");
for i in range(5):
print("  count:",i+1)
# Draw a black filled box to clear the image.
draw.rectangle((0, 0, width, height), outline=0, fill=0)
# Print the IP address
"""
Two examples here, wired and wireless
draw.text((0, 0), "eth0: " + str(get_ip_address('eth0')),  font=font, fill=255)
draw.text((0, 0), "wlan0: " + str(get_ip_address('wlan0')), font=font, fill=255)
"""
draw.text((0, 0), "IPadr: " + str(get_ip_address('wlan0')), font=font, fill=255)
draw.text((0,8), "Tempe: " +str(round(bme280.temperature + adj_t,1)),font=font, fill=255)
draw.text((0,16), "Humid: " +str(round(bme280.humidity + adj_h,1)),font=font, fill=255)
draw.text((0,24), "Press: " +str(round(bme280.pressure + adj_p,1)),font=font, fill=255)
# draw.text((0,32), "Altit: " +str(round(bme280.altitude + adj_a,1)),font=font, fill=255)

# Display image.
# Set the SSD1306 image to the PIL image we have made, then dispaly
disp.image(image)
disp.display()
time.sleep(2)

GPIO.cleanup()

# ------------------------------------------ l-chika ------------------------------

# Pin Definitions
pin1 = 20   # BOARD pin 38, BCM pin 20

cur=1
# Pin Setup:
# Board pin-numbering scheme
GPIO.setmode(GPIO.BCM)
# set pin as an output pin with optional initial state of HIGH
GPIO.setup(pin1, GPIO.OUT, initial=GPIO.LOW)
print(">>> Blinking LED ...")
for i in range(10):
    time.sleep(1)
    # Toggle the output every second
    if cur>0:
        print("  LED ON")
    else:
        print("  LED OFF")
    GPIO.output(pin1, cur)
    cur = 1-cur
GPIO.output(pin1,0)
GPIO.cleanup()

# ---------------------------------- servo motor -----------------------------
# Initialise the PCA9685 using the default address (0x40).
pwm = Adafruit_PCA9685.PCA9685()
 
# Alternatively specify a different address and/or bus:
#pwm = Adafruit_PCA9685.PCA9685(address=0x41, busnum=2)
 
# Configure min and max servo pulse lengths
servo_min = 300  # Min pulse length out of 4096 default 150
servo_max = 450  # Max pulse length out of 4096 default 600
servo_ini = 375
print(">>> Moving Servo motor ...")
# Helper function to make setting a servo pulse width simpler.print(">>> 
def set_servo_pulse(channel, pulse):
    pulse_length = 1000000    # 1,000,000 us per second
    pulse_length //= 60       # 60 Hz
    #print('{0}us per period'.format(pulse_length))
    pulse_length //= 4096     # 12 bits of resolution
    #print('{0}us per bit'.format(pulse_length))
    pulse *= 1000
    pulse //= pulse_length
    pwm.set_pwm(channel, 0, pulse)
 
# Set frequency to 60hz, good for servos.
pwm.set_pwm_freq(60)

for c in range(2):
# Move servo on channel O between extremes.
pwm.set_pwm(0, 0, servo_ini)
pwm.set_pwm(1, 0, servo_ini)
time.sleep(1)
for i in range(2):
    if i==0: print("  Move Horizontal")
    else: print("  Move Vertical")
    pwm.set_pwm(i, 0, servo_min)
    time.sleep(1)
    pwm.set_pwm(i, 0, servo_max)
    time.sleep(1)
    pwm.set_pwm(0, 0, servo_ini)
    pwm.set_pwm(1, 0, servo_ini)
    time.sleep(1)
GPIO.cleanup()

# ---------------------------------------------- dc-motor ----------------------
# Pin Definitions
pin2 = 18  # BOARD pin 12, BCM pin 18
pin3 = 24  # BOARD pin 18, BCM pin 24
print(">>> Moving DC motor ...")
cur=0
# Pin Setup:
# Board pin-numbering scheme
GPIO.setmode(GPIO.BCM)
GPIO.setup(pin2, GPIO.OUT, initial=cur)
GPIO.setup(pin3, GPIO.OUT, initial=cur)

for i in range(4):   
    GPIO.output(pin2,0)
    GPIO.output(pin3,0)
    time.sleep(1)
    # Toggle the output every second
    if cur==0: print("  Clockwise")
    else: print ("  Counter-clockwise")
    GPIO.output(pin2, cur)
    GPIO.output(pin3, 1-cur)
    cur = 1-cur
    time.sleep(8)
GPIO.output(pin2,0)
GPIO.output(pin3,0)

GPIO.cleanup()
print("*** End of Experiment ***")
